@@ -9,8 +9,8 @@ from packaging import version
 
 from dvc import __version__
 from dvc.lock import Lock, LockError
-from dvc.utils import is_binary, boxify, env2bool
-
+from dvc.utils import boxify, env2bool
+from dvc.utils.pkg import get_package_manager
 
 logger = logging.getLogger(__name__)
 
@@ -123,7 +123,6 @@ class Updater(object):  # pragma: no cover
             "yum": "Run {yellow}yum{reset} update dvc",
             "yay": "Run {yellow}yay{reset} {blue}-S{reset} dvc",
             "formula": "Run {yellow}brew{reset} upgrade dvc",
-            "cask": "Run {yellow}brew cask{reset} upgrade dvc",
             "apt": (
                 "Run {yellow}apt-get{reset} install"
                 " {blue}--only-upgrade{reset} dvc"
@@ -141,60 +140,6 @@ class Updater(object):  # pragma: no cover
             ),
         }
 
-        package_manager = self._get_package_manager()
+        package_manager = get_package_manager()
 
         return instructions[package_manager]
-
-    def _get_linux(self):
-        import distro
-
-        if not is_binary():
-            return "pip"
-
-        package_managers = {
-            "rhel": "yum",
-            "centos": "yum",
-            "fedora": "yum",
-            "amazon": "yum",
-            "opensuse": "yum",
-            "ubuntu": "apt",
-            "debian": "apt",
-        }
-
-        return package_managers.get(distro.id())
-
-    def _get_darwin(self):
-        if not is_binary():
-            if __file__.startswith("/usr/local/Cellar"):
-                return "formula"
-            else:
-                return "pip"
-
-        # NOTE: both pkg and cask put dvc binary into /usr/local/bin,
-        # so in order to know which method of installation was used,
-        # we need to actually call `brew cask`
-        ret = os.system("brew cask ls dvc")
-        if ret == 0:
-            return "cask"
-
-        return None
-
-    def _get_windows(self):
-        return None if is_binary() else "pip"
-
-    def _get_package_manager(self):
-        import platform
-        from dvc.exceptions import DvcException
-
-        m = {
-            "Windows": self._get_windows,
-            "Darwin": self._get_darwin,
-            "Linux": self._get_linux,
-        }
-
-        system = platform.system()
-        func = m.get(system)
-        if func is None:
-            raise DvcException("not supported system '{}'".format(system))
-
-        return func()
